# История изменений

## 1.3.0 (2026-02-13)

- Повышение версии edu-to-analytics-service до 1.2.0

## 1.2.0 (2026-02-12)

- Убрана зависимость от pkg_resources

## 1.1.0 (2026-02-02)

- Добавлена поддержка Django 4.2

## 1.0.3 (2024-11-12)

- Добавлена поддержка Django 3.2

## 1.0.2 (2024-03-01)

- Добавлена поддержка Django 3.1

## 1.0.1 (2024-01-22)

- Добавлена поддержка Django 3.0

## 1.0.0 (2023-07-26)

- Удалена поддержка Python 2
- В зависимостях поднята поддерживаемая версия m3-spyne-smev

## 0.4.0 (2022-10-01)

- В зависимостях поднята поддерживаемая версия Django

## 0.3.1 (2020-02-11)

- Исправлена ошибка кодирования при отправке ответа

## 0.3.0 (2019-04-11)

- Добавлена поддержка версии pip>=10

## 0.2.0 (2019-03-20)

- Добавлена возможность асинхронного сбора показателей

## 0.1.1 (2017-03-28)

- Исправлена ошибка при сборе показателей за конкретный день

## 0.1.0 (2017-02-14)

- Интеграция с Аналитической системой ТО для ЭШ
